﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using Telerik.Charting;
using Telerik.Windows.Controls;
using Telerik.Windows.Controls.ChartView;

namespace SLApp
{
    public partial class MainPage : UserControl
    {
        public MainPage()
        {
            InitializeComponent();

            this.chart.LayoutUpdated += chart_LayoutUpdated;
        }

        void chart_LayoutUpdated(object sender, EventArgs e)
        {
            var plotAreaBorder = chart.ChildrenOfType<Border>().Where(b => b.Name == "plotAreaDecoration").SingleOrDefault();
            if (plotAreaBorder != null)
            {
                plotAreaBorder.Background = new SolidColorBrush(Colors.Transparent);
                plotAreaBorder.MouseLeftButtonUp += PlotAreaBorder_MouseLeftButtonUp;

                this.chart.LayoutUpdated -= chart_LayoutUpdated;
            }
        }

        private Point annotationStart;
        private Point annotationEnd;
        private AnnotationCreationState state = AnnotationCreationState.NotStarted;

        void PlotAreaBorder_MouseLeftButtonUp(object sender, MouseButtonEventArgs e)
        {
            var mousePosition = e.GetPosition(this.chart);

            switch (state)
            {
                case AnnotationCreationState.NotStarted:
                    {
                        this.annotationStart = mousePosition;
                        this.state = AnnotationCreationState.StartPointSet;
                        break;
                    }
                case AnnotationCreationState.StartPointSet:
                    {
                        this.annotationEnd = mousePosition;                        

                        double x1 = (double)this.chart.ConvertPointToData(this.annotationStart).FirstlValue;
                        double y1 = (double)this.chart.ConvertPointToData(this.annotationStart).SecondValue;
                        double x2 = (double)this.chart.ConvertPointToData(this.annotationEnd).FirstlValue;
                        double y2 = (double)this.chart.ConvertPointToData(this.annotationEnd).SecondValue;

                        var lineAnnotation = new ScatterLineSeries();
                        lineAnnotation.DataPoints.Add(new ScatterDataPoint { XValue = x1, YValue = y1 });
                        lineAnnotation.DataPoints.Add(new ScatterDataPoint { XValue = x2, YValue = y2 });

                        this.chart.Series.Add(lineAnnotation);


                        this.state = AnnotationCreationState.NotStarted;
                        break;
                    }
                default:
                    break;
            }


        }

        enum AnnotationCreationState
        {
            NotStarted,
            StartPointSet
        }
    }

    public class ViewModel
    {
        private static readonly Random rnd = new Random();

        public ObservableCollection<PlotInfo> Data { get; set; }

        public ViewModel()
        {
            this.Data = GetData(15);
        }

        public static ObservableCollection<PlotInfo> GetData(int dataSize)
        {
            var result = new ObservableCollection<PlotInfo>();

            for (int i = 0; i < dataSize; i++)
            {
                result.Add(new PlotInfo { XVal = i, YVal = rnd.Next(0, 100) });
            }

            return result;
        }
    }

    public class PlotInfo
    {
        public double XVal { get; set; }

        public double YVal { get; set; }
    }
}